﻿namespace U2UC.WinUni.LexDBSample.DataAccess
{
    using Lex.Db;
    using System;
    using System.Collections.Generic;
    using System.Text;
    using Windows.Storage;
    using Models;
    using System.Threading.Tasks;

    public static class Dal
    {
        private static DbInstance db;

        static Dal()
        {
            // Create database
            db = new DbInstance("Storage", ApplicationData.Current.RoamingFolder);

            // Define table mapping
            // * 1st parameter is primary key
            // * 2nd parameter is autoGen e.g. auto-increment
            db.Map<Person>().Automap(p => p.Id, true);

            // Initialize database
            db.Initialize();
        }

        public static IEnumerable<Person> GetPeople()
        {
            return db.Table<Person>();
        }

        public static int SavePerson(Person person)
        {
            db.Table<Person>().Save(person);
            return person.Id;
        }

        public static Task SavePeople(IEnumerable<Person> people)
        {
            return db.Table<Person>().SaveAsync(people);
        }

        public static Task DeletePeople(IEnumerable<Person> people)
        {
            return db.Table<Person>().DeleteAsync(people);
        }

        public static Task ResetPeople()
        {
            // Clear
            db.Purge<Person>();

            // Repopulate
            return Dal.SavePeople(
                new List<Person>()
                {
                    new Person() { Name="Leonard Leakey Hofstadter", Degree="Ph.D.", Occupation="Experimental physicist"},
                    new Person() {Name="Sheldon Lee Cooper", Degree="Ph.D.", Occupation="Theoretical physicist"},
                    new Person() {Name="Howard Joel Wolowitz", Degree="M.Eng.", Occupation="Aerospace engineer"},
                    new Person() {Name="Rajesh Ramayan Koothrappali", Degree="Ph.D.", Occupation="Astrophysicist"}
                });
        }
    }
}
