﻿namespace U2UC.WinUni.LexDBSample.ViewModels
{
    using DataAccess;
    using Models;
    using Mvvm;
    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using System.Windows.Input;

    internal class MainPageViewModel : BindableBase
    {
        private ObservableCollection<Person> people = new ObservableCollection<Person>();
        private Person selectedPerson;
        private RelayCommand resetCommand;
        private RelayCommand addCommand;
        private RelayCommand deleteCommand;

        public MainPageViewModel()
        {
            this.resetCommand = new RelayCommand(this.Reset_Executed);
            this.addCommand = new RelayCommand(this.Add_Executed);
            this.deleteCommand = new RelayCommand(this.Delete_Executed, this.Delete_CanExecute);

            this.RefreshPeople();
        }

        public ObservableCollection<Person> People
        {
            get { return this.people; }
        }

        public Person SelectedPerson
        {
            get
            {
                return this.selectedPerson;
            }

            set
            {
                this.SetProperty(ref this.selectedPerson, value);
                this.deleteCommand.RaiseCanExecuteChanged();
            }
        }

        public ICommand ResetCommand
        {
            get { return this.resetCommand; }
        }

        public ICommand AddCommand
        {
            get { return this.addCommand; }
        }

        public ICommand DeleteCommand
        {
            get { return this.deleteCommand; }
        }

        private async void Reset_Executed()
        {
            await Dal.ResetPeople();
            this.RefreshPeople();
        }

        private void Add_Executed()
        {
            var person = new Person() { Name = "<Your name here>", Degree = "M.Sci.", Occupation = "Universal app developer" };
            person.Id = Dal.SavePerson(person);
            this.people.Add(person);
        }

        private bool Delete_CanExecute()
        {
            return this.selectedPerson != null;
        }

        private async void Delete_Executed()
        {
            await Dal.DeletePeople(new List<Person>() { this.selectedPerson });
            this.people.Remove(this.selectedPerson);
        }

        private void RefreshPeople()
        {
            this.people.Clear();
            this.people.AddRange(Dal.GetPeople());
        }
    }
}
